@@ -21,6 +21,7 @@ use smartstring::alias::String as SmartString;
 use std::{
     borrow::{Borrow, Cow},
     convert::Infallible,
+    ffi::OsStr,
     fmt::{self, Error as FmtError, Write as FmtWrite},
     iter::FromIterator,
     path::Path,
@@ -169,6 +170,12 @@ impl AsRef<Path> for StackString {
     }
 }
 
+impl AsRef<OsStr> for StackString {
+    fn as_ref(&self) -> &OsStr {
+        self.as_str().as_ref()
+    }
+}
+
 impl FromStr for StackString {
     type Err = Infallible;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
